# for geometry
import geompy
import math
import SALOMEDS

# for meshing
import salome, SMESH
import smesh
 

null = geompy.MakeVertex(0, 0, 0)
p1 = geompy.MakeVertex(25, 0, 0)
p2 = geompy.MakeVertex(29, 0, 0)
p3 = geompy.MakeVertex(2, 25, 0)
p4 = geompy.MakeVertex(-2, 25, 0)
p5 = geompy.MakeVertex(-29, 0, 0)
p6 = geompy.MakeVertex(-25, 0, 0)
p7 = geompy.MakeVertex(-2.2, 22.0, 0)
p8 = geompy.MakeVertex( 2.2, 22.0, 0)


L_1 = geompy.MakeLineTwoPnt(p1, p2)
L_2 = geompy.MakeLineTwoPnt(p2, p3)
L_3 = geompy.MakeLineTwoPnt(p3, p4)
L_4 = geompy.MakeLineTwoPnt(p4, p5)
L_5 = geompy.MakeLineTwoPnt(p5, p6)
L_6 = geompy.MakeLineTwoPnt(p6, p7)
L_7 = geompy.MakeLineTwoPnt(p7, p8)
L_8 = geompy.MakeLineTwoPnt(p8, p1)


Face_1 = geompy.MakeFaceWires([L_1, L_2, L_3, L_4, L_5, L_6, L_7, L_8], 1)

width = 10.0
Extr1 = geompy.MakePrismDXDYDZ(Face_1, 0, 0, width)

# define interesting points, edges and planes
Nforce = geompy.CreateGroup(Extr1, geompy.ShapeType["VERTEX"])
geompy.UnionIDs(Nforce, [44])
Extr1 = geompy.GetMainShape(Nforce)

Lleft = geompy.CreateGroup(Extr1, geompy.ShapeType["EDGE"])
geompy.UnionIDs(Lleft, [5])
Extr1 = geompy.GetMainShape(Lleft)
Lright = geompy.CreateGroup(Extr1, geompy.ShapeType["EDGE"])
geompy.UnionIDs(Lright, [36])
Extr1 = geompy.GetMainShape(Lright)


Pright = geompy.CreateGroup(Extr1, geompy.ShapeType["FACE"])
geompy.UnionIDs(Pright, [3])
Extr1 = geompy.GetMainShape(Pright)
Pleft = geompy.CreateGroup(Extr1, geompy.ShapeType["FACE"])
geompy.UnionIDs(Pleft, [34])
Extr1 = geompy.GetMainShape(Pleft)
top = geompy.CreateGroup(Extr1, geompy.ShapeType["FACE"])
geompy.UnionIDs(top, [48])
Extr1 = geompy.GetMainShape(top)

geompy.addToStudy( null, "null" )
geompy.addToStudy( p1, "p1" )
geompy.addToStudy( p2, "p2" )
geompy.addToStudy( p3, "p3" )
geompy.addToStudy( p4, "p4" )
geompy.addToStudy( p5, "p5" )
geompy.addToStudy( p6, "p6" )
geompy.addToStudy( p7, "p7" )
geompy.addToStudy( p8, "p8" )

geompy.addToStudy( L_1, "Line1" )
geompy.addToStudy( L_2, "Line2" )
geompy.addToStudy( L_3, "Line3" )
geompy.addToStudy( L_4, "Line4" )
geompy.addToStudy( L_5, "Line5" )
geompy.addToStudy( L_6, "Line6" )
geompy.addToStudy( L_7, "Line7" )
geompy.addToStudy( L_8, "Line8" )

geompy.addToStudy( Extr1, "Extr1" )

fix = geompy.CreateGroup(Extr1, geompy.ShapeType["FACE"])
geompy.UnionList(fix, [Pright, Pleft])



# to be used in mesh
geompy.addToStudyInFather( Extr1, Pright, "Pright" )
geompy.addToStudyInFather( Extr1, Pleft,  "Pleft" )
geompy.addToStudyInFather( Extr1, top,    "top" )
geompy.addToStudyInFather( Extr1, fix,    "fix" )

	



### mesh part
first_second_order = 1 # first: 0 second: 1
MaxVolSize = 5.0       # maximum size of elements
Optimise = 1           # no: 0 yes: 1
Fineness = 3           # on scale from 0 (course) to 5 (fine)

vbeam = smesh.Mesh(Extr1)
Netgen_1D_2D_3D = vbeam.Tetrahedron(algo=smesh.FULL_NETGEN)
NETGEN_3D_Parameters = Netgen_1D_2D_3D.Parameters()
NETGEN_3D_Parameters.SetOptimize( Optimise )
NETGEN_3D_Parameters.SetFineness( Fineness )
NETGEN_3D_Parameters.SetMaxSize( MaxVolSize  )
NETGEN_3D_Parameters.SetSecondOrder( first_second_order )
isDone = vbeam.Compute()

## set object names
smesh.SetName(vbeam.GetMesh(),'Mvbeam')
smesh.SetName(Netgen_1D_2D_3D.GetAlgorithm(), 'Netgen 1D-2D-3D')
smesh.SetName(NETGEN_3D_Parameters, 'NETGEN 3D Parameters')

Pright.SetColor(SALOMEDS.Color(0.6, 0.1, 0.1 ))
Pleft.SetColor(SALOMEDS.Color(0.6, 0.1, 0.1 ))

## set object names
smesh.SetName(vbeam.GetMesh(), 'vbeam')
smesh.SetName(Netgen_1D_2D_3D.GetAlgorithm(), 'Netgen 1D-2D-3D')
smesh.SetName(NETGEN_3D_Parameters, 'NETGEN 3D Parameters')


fix = vbeam.Group(fix)
top = vbeam.Group(top)

	## set object names
smesh.SetName(fix, 'fix')
smesh.SetName(top, 'top')
smesh.SetName(Pright, 'Pright')
smesh.SetName(Pleft,  'Pleft')


if salome.sg.hasDesktop():
    salome.sg.updateObjBrowser(0)


